==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/gl/lang.php <==
<?php
/**
 * Galicianlanguage file
 *
 * @author Medúlio <medulio@ciberirmandade.org>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Rodrigo Rega <rodrigorega@gmail.com>
 */
$lang['admin_acl']             = 'Xestión da Lista de Control de Acceso (ACL)';
$lang['acl_group']             = 'Grupo';
$lang['acl_user']              = 'Usuario';
$lang['acl_perms']             = 'Permisos para';
$lang['page']                  = 'Páxina';
$lang['namespace']             = 'Nome de espazo';
$lang['btn_select']            = 'Escolle';
$lang['p_user_id']             = 'O usuario <b class="acluser">%s</b> dispón actualmente dos seguintes permisos na páxina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'O usuario <b class="acluser">%s</b> dispón actualmente dos seguintes permisos no nome de espazo <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Os membros do grupo <b class="aclgroup">%s</b> dispoñen actualmente dos seguintes permisos na páxina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Os membros do grupo <b class="aclgroup">%s</b> cdispoñen actualmente dos seguintes permisos no nome de espazo <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor, <b>insire un usuario ou grupo</b> no formulario de enriba para ver ou editar os permisos establecidos para a páxina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>insire un usuario ou grupo</b> no formulario de enriba para ver ou editar os permisos establecidos no nome de espazo <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Estes permisos non foron establecidos explicitamente senón que foron herdadas de outros grupos ou nomes de espazo meirandes.';
$lang['p_isadmin']             = 'Nota: O grupo ou usuario seleccionado terá sempre permisos completos por estar configurado como super-usuario.';
$lang['p_include']             = 'Os permisos meirandes inclúen os menores. Os permisos de Creación, Subida e Eliminado só se aplican aos nomes de espazo, non ás páxinas.';
$lang['current']               = 'Regras ACL Actuais';
$lang['where']                 = 'Páxina/Nome de Espazo';
$lang['who']                   = 'Usuario/Grupo';
$lang['perm']                  = 'Permisos';
$lang['acl_perm0']             = 'Ningún';
$lang['acl_perm1']             = 'Ler';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Crear';
$lang['acl_perm8']             = 'Subir arquivos';
$lang['acl_perm16']            = 'Eliminar';
$lang['acl_new']               = 'Engadir nova Entrada';
$lang['acl_mod']               = 'Modificar Entrada';

==> dokuwiki_0.0.20160626.a.orig.tar.gz: dokuwiki-2016-06-26a/lib/plugins/acl/lang/gl/lang.php <==
<?php
/**
 * Galicianlanguage file
 *
 * @author Medúlio <medulio@ciberirmandade.org>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Rodrigo Rega <rodrigorega@gmail.com>
 */
$lang['admin_acl']             = 'Xestión da Lista de Control de Acceso (ACL)';
$lang['acl_group']             = 'Grupo:';
$lang['acl_user']              = 'Usuario:';
$lang['acl_perms']             = 'Permisos para';
$lang['page']                  = 'Páxina';
$lang['namespace']             = 'Nome de espazo';
$lang['btn_select']            = 'Escolle';
$lang['p_user_id']             = 'O usuario <b class="acluser">%s</b> dispón actualmente dos seguintes permisos na páxina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'O usuario <b class="acluser">%s</b> dispón actualmente dos seguintes permisos no nome de espazo <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Os membros do grupo <b class="aclgroup">%s</b> dispoñen actualmente dos seguintes permisos na páxina <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Os membros do grupo <b class="aclgroup">%s</b> cdispoñen actualmente dos seguintes permisos no nome de espazo <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Por favor, <b>insire un usuario ou grupo</b> no formulario de enriba para ver ou editar os permisos establecidos para a páxina <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Por favor <b>insire un usuario ou grupo</b> no formulario de enriba para ver ou editar os permisos establecidos no nome de espazo <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Nota: Estes permisos non foron establecidos explicitamente senón que foron herdadas de outros grupos ou nomes de espazo meirandes.';
$lang['p_isadmin']             = 'Nota: O grupo ou usuario seleccionado terá sempre permisos completos por estar configurado como super-usuario.';
$lang['p_include']             = 'Os permisos meirandes inclúen os menores. Os permisos de Creación, Subida e Eliminado só se aplican aos nomes de espazo, non ás páxinas.';
$lang['current']               = 'Regras ACL Actuais';
$lang['where']                 = 'Páxina/Nome de Espazo';
$lang['who']                   = 'Usuario/Grupo';
$lang['perm']                  = 'Permisos';
$lang['acl_perm0']             = 'Ningún';
$lang['acl_perm1']             = 'Ler';
$lang['acl_perm2']             = 'Editar';
$lang['acl_perm4']             = 'Crear';
$lang['acl_perm8']             = 'Subir arquivos';
$lang['acl_perm16']            = 'Eliminar';
$lang['acl_new']               = 'Engadir nova Entrada';
$lang['acl_mod']               = 'Modificar Entrada';
